package com.sooka.sponest.monitor.dahua.mapper;

import com.alibaba.fastjson.JSONObject;
import com.sooka.sponest.monitor.dahua.domain.CenternonitorTDahuaOperateLog;
import com.sooka.sponest.monitor.dahua.vo.ChannelCodeVO;
import org.apache.ibatis.annotations.Param;

import java.util.LinkedHashMap;
import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2023-12-09
 */
public interface CenternonitorTDahuaOperateLogMapper {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    CenternonitorTDahuaOperateLog selectCenternonitorTDahuaOperateLogById(CenternonitorTDahuaOperateLog centernonitorTDahuaOperateLog);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param centernonitorTDahuaOperateLog 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    List<CenternonitorTDahuaOperateLog> selectCenternonitorTDahuaOperateLogList(CenternonitorTDahuaOperateLog centernonitorTDahuaOperateLog);

    Integer selectExportList(CenternonitorTDahuaOperateLog centernonitorTDahuaOperateLog);

    /**
     * 新增【请填写功能名称】
     *
     * @param centernonitorTDahuaOperateLog 【请填写功能名称】
     * @return 结果
     */
    int insertCenternonitorTDahuaOperateLog(CenternonitorTDahuaOperateLog centernonitorTDahuaOperateLog);

    /**
     * 修改【请填写功能名称】
     *
     * @param centernonitorTDahuaOperateLog 【请填写功能名称】
     * @return 结果
     */
    int updateCenternonitorTDahuaOperateLog(CenternonitorTDahuaOperateLog centernonitorTDahuaOperateLog);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    int deleteCenternonitorTDahuaOperateLogById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCenternonitorTDahuaOperateLogByIds(Long[] ids);

    /**
     * 批量保存大华云台日志
     */
    int insertBatch(@Param("list") List<CenternonitorTDahuaOperateLog> list);

    /**
     * 获取设备名称
     */
    List<ChannelCodeVO> selectDeviceNameList();

    /**
     * 根据时间和类型删除华云台日志
     */
    void deleteByDate(@Param("startTime") String startTime, @Param("endTime") String endTime, @Param("operateTypeValue") String operateTypeValue);

    int updateFourField(CenternonitorTDahuaOperateLog centernonitorTDahuaOperateLog);

    LinkedHashMap<String, Object> selectOperateLogCountByDeptId(JSONObject jsonObject);

    List<Long> selectOperLogLimit(@Param("year") String year);
}
